Data
====


.. automodule:: cornac.data
    :members:
	
Dataset
------------------------------------
.. automodule:: cornac.data.dataset
   :members:

Modality
---------------------------------
.. automodule:: cornac.data.modality
   :members:

Graph Modality
---------------------------------
.. automodule:: cornac.data.graph
   :members:

Text Modality
---------------------------------
.. automodule:: cornac.data.text
   :members:

Image Modality
---------------------------------
.. automodule:: cornac.data.image
   :members:

Sentiment Modality
---------------------------------
.. automodule:: cornac.data.sentiment
   :members:

Reader
----------------------------------
.. automodule:: cornac.data.reader
   :members:
